# PUM API

- [Changelog](api/changelog.md)
- [Hook](api/hook.md)
- [Hook](api/hook_handler.md)
- [ParameterDefinition](api/parameter_definition.md)
- [ParameterType](api/parameter_type.md)
- [PumConfig](api/pum_config.md)
- [SchemaMigrations](api/schema_migrations.md)
- [Upgrader](api/upgrader.md)
- [Exceptions](api/exceptions.md)
